==> kimageannotator_0.6.0.orig.tar.gz: kImageAnnotator-0.6.0/translations/kImageAnnotator_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Упорядочить</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>На верхний слой</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>На слой выше</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>На слой ниже</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>На нижний слой</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Выбрать этот</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Вставить</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Изменить</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation>Общие настройки</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation>Настройки изображения</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>Цвет</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Цвет текста</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Ширина</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation>Нумератор</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>Уровень обфускации</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation>Тень элемента</translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation>Настройки элемента</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Закрыть остальные</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Закрыть все</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Закрыть все слева</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Закрыть все справа</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation>Выбор инструмента</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>Включено</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Отключено</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>Ш:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>В:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Применить</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>Видимость обводки и заливки</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>Обводка и заливка</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>Обводка без заливки</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>Без обводки и заливки</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation>Размер шрифта</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Жирный</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Курсив</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Подчёркнутый</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>Графические эффекты</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>Без эффекта</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>Отбросить тень</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>Оттенки серого</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Рамка</translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation>Инвертировать цвет</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation>Ограничено</translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation>Включить принудительный захват
фонового изображения.</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>Ширина:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>Высота:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Применить</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Цвет:</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation>Цвет фона</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation>Повернуть изображение</translation>
    </message>
    <message>
        <source>180°</source>
        <translation>180°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation>90° по часовой стрелке</translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation>90° против часовой стрелки</translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation>Задать угол</translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation>Положительные значения — по часовой стрелке, отрицательные — против.
Поворот на некратный 90° угол может привести к потере качества.</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Горизонально</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Вертикально</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Применить</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Повернуть</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>Отразить</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Масштабировать изображение</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Сохранять пропорции</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Ширина:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Высота:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Применить</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Пиксели</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Проценты</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>Стикер</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Выбор</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Карандаш</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Число</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Маркер прямоугольный</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Маркер эллипсом</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Маркер карандаш</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Текст</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Стрелка</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Двойная стрелка</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Линия</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Размытие</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Прямоугольник</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Эллипс</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Числовой указатель</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Стикер</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>Пикселизовать</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>Текстовый указатель</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>Стрелка с текстом</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>Стрелка с цифрой</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Дублировать</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation>Увеличить (%1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation>Уменьшить (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation>Исходный масштаб (%1)</translation>
    </message>
</context>
</TS>

==> kimageannotator_0.7.2.orig.tar.gz: kImageAnnotator-0.7.2/translations/kImageAnnotator_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Упорядочить</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>На верхний слой</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>На слой выше</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>На слой ниже</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>На нижний слой</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Выбрать этот</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Вставить</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Изменить</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationControlsWidget</name>
    <message>
        <source>Controls</source>
        <translation>Элементы управления</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation>Общие настройки</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation>Настройки изображения</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>Цвет</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Цвет текста</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Ширина</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation>Нумератор</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>Уровень обфускации</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation>Тень элемента</translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation>Настройки элемента</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Масштаб</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>Прозрачность</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Закрыть остальные</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Закрыть все</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Закрыть все слева</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Закрыть все справа</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation>Выбор инструмента</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>Включено</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Отключено</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::Controls</name>
    <message>
        <source>Undo</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Повторить</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Обрезать</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Масштабировать</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Повернуть</translation>
    </message>
    <message>
        <source>Modify canvas</source>
        <translation>Изменить холст</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Вырезать</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>Ш:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>В:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Применить</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CutWidget</name>
    <message>
        <source>Vertical</source>
        <translation>Вертикально</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Горизонально</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Применить</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отменить</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>Видимость обводки и заливки</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>Обводка и заливка</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>Обводка без заливки</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>Без обводки и заливки</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation>Размер шрифта</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Жирный</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Курсив</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Подчёркнутый</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>Графические эффекты</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>Без эффекта</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>Отбросить тень</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>Оттенки серого</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Рамка</translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation>Инвертировать цвет</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation>Ограничено</translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation>Включить принудительный захват
фонового изображения.</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>Ширина:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>Высота:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Применить</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Цвет:</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation>Цвет фона</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation>Повернуть изображение</translation>
    </message>
    <message>
        <source>180°</source>
        <translation>180°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation>90° по часовой стрелке</translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation>90° против часовой стрелки</translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation>Задать угол</translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation>Положительные значения — по часовой стрелке, отрицательные — против.
Поворот на некратный 90° угол может привести к потере качества.</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Горизонально</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Вертикально</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Применить</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Повернуть</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>Отразить</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Масштабировать изображение</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Сохранять пропорции</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Ширина:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Высота:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Применить</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Пиксели</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Проценты</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>Стикер</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Выбор</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Карандаш</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Число</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Маркер прямоугольный</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Маркер эллипсом</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Маркер карандаш</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Текст</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Стрелка</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Двойная стрелка</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Линия</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Размытие</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Прямоугольник</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Эллипс</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Числовой указатель</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Стикер</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>Пикселизовать</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>Текстовый указатель</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>Стрелка с текстом</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>Стрелка с цифрой</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Дублировать</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation>Увеличить (%1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation>Уменьшить (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation>Исходный масштаб (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom</source>
        <translation>Исходный масштаб</translation>
    </message>
    <message>
        <source>Fit Image</source>
        <translation>Изображение целиком</translation>
    </message>
    <message>
        <source>Fit image to view (%1)</source>
        <translation>Изображение целиком (%1)</translation>
    </message>
</context>
</TS>
